@@ -315,7 +315,6 @@ def s3downloader(**kwargs):
                 obj = client.get_object(Bucket=bucketname, Key=full_object_key)
                 content_length = obj['ContentLength']
                 strbody = obj['Body']
-                bts = strbody.read()
                 dtm = obj['LastModified']
                 key = dtm.strftime('%Y-%m-%d %H:%M:%S') + ' ' + bucketname + '/' + full_object_key
             else:
@@ -341,7 +340,8 @@ def s3downloader(**kwargs):
                     write_pipe.send(key)
                     write_pipe.send(filename)
                     if (tmpfile_dir == None):
-                        write_pipe.send(bts)
+                        for chunk in strbody.iter_chunks(8192):
+                            write_pipe.send(chunk)
                     else:
                         write_pipe.send('Success')
                 except Exception as e:
